# -*- coding: utf-8 -*-
require 'net/http'
require 'json'

# TumblrのAPIを簡単にラップしたクラス。
# RESTful APIを用いて手軽にアクセスすることを目的とする。
# @author Uchio KONDO <udzura@udzura.jp>
# @version 0.0.1
class TumblrApiWrapper
  API_BASE = "http://api.tumblr.com/v2"

  # ラッパクラスの初期化メソッド。
  # @param [String] api_key TumblrのAPIキー。
  #   TumblrのOAuth Consumerキーを指定する。
  #   キーの取得の詳細はTumblrのドキュメントを参照。
  def initialize(api_key)
    @api_key = api_key
  end

  # @return [String] 初期化時に設定したAPIキー
  attr_reader :api_key

  # Tumblr ブログのドメインを渡すと、
  # そのブログの詳細な情報を返す。
  # @param [String] blog_domain 対象ブログのドメイン名
  # @return [Hash] そのブログの詳細情報
  # @yield [response] ブロックを伴うときは、
  #   ブログのレスポンス情報がブロックパラメータとなる
  # @example `foo.tumblr.com` のタイトル情報を取得する場合
  #   api.get_blog_info "foo.tumblr.com" do |info|
  #     p "Title: " + info["blog"]["title"]
  #   end
  # @raise [RuntimeError] もしブログが見つからないなど、
  #   正しく情報が取得できなかった場合エラーとする
  def get_blog_info(blog_domain)
    uri_string = \
      "#{API_BASE}/blog/#{blog_domain}/info" +
      "?api_key=#{api_key}"
    json = Net::HTTP.get(URI.parse(uri_string))
    response = JSON.parse(json)
    if response["meta"]["status"] != 200
      raise "Something is wrong"
    end
    yield(response["response"]) if block_given?
    response["response"]
  end

  # @deprecated 昔のAPI。名前のみでは使いづらいため。
  #   現バージョンでは {#get_blog_info} を利用せよ。
  def get_blog_info_by_user_name(name)
    get_blog_info("#{name}.tumblr.com")
  end
end
